==> openGion6.4.7.0_src.zip: gf/src/org/opengion/plugin/column/Editor_COLOR.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractEditor;
import org.opengion.hayabusa.db.CellEditor;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.XHTMLTag;

import static org.opengion.fukurou.util.StringUtil.isNull;				// 6.1.1.0 (2015/01/17)

/**
 * COLOR エディターは、カラムのデータをカラーピッカーで選択する場合に使用するクラスです。
 * 値は#FFFFFFのように#付き7桁で入ります。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ編集
 *
 * @og.rev 5.5.4.0 (2012/07/02) 新規作成
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Editor_COLOR extends AbstractEditor {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "6.3.6.1 (2015/08/28)" ;

	// 6.3.6.1 (2015/08/28) style属性のマージ
	private final String style;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 */
	public Editor_COLOR() {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		style = null;
	}

	/**
	 * コンストラクター。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Editor_COLOR( final DBColumn clm ) {
		super( clm );
		style = attributes.remove( "style" );		// 6.3.6.1 (2015/08/28) あれば、キーから削除。

		attributes.add( "class"		,"colorPicker" );
		attributes.add( "readonly"	,"readonly" );
		tagBuffer.add( XHTMLTag.inputAttri( attributes ) );
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellEditorオブジェクト
	 * @og.rtnNotNull
	 */
	public CellEditor newInstance( final DBColumn clm ) {
		return new Editor_COLOR( clm );
	}

	/**
	 * データの編集用文字列を返します。(色付き)
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 *
	 * @param	value 入力値
	 *
	 * @return	データの編集用文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final String value ) {
		// 6.3.6.1 (2015/08/28) style属性のマージ
		final String inStyle = style == null ? "background-color:"+value+"; color:"+value+";"
											 : style + "background-color:"+value+"; color:"+value+";" ;

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		return new TagBuffer( "input" )
					.add( "name"	, name )
					.add( "id"		, name , isNull( attributes.get( "id" ) ) )		// 4.3.7.2 (2009/06/15)
					.add( "value"	, value )
					.add( "size"	, size1 )
//					.add( "style"	, "background-color:"+value+"; color:"+value+";" )
					.add( "style"	, inStyle )
					.add( tagBuffer.makeTag() )
					.makeTag();
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。(色付き)
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 *
	 * @param	row   行番号
	 * @param	value 入力値
	 *
	 * @return	データ表示/編集用の文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final int row,final String value ) {
		final String newName = name + HybsSystem.JOINT_STRING + row;

		// 6.3.6.1 (2015/08/28) style属性のマージ
		final String inStyle = style == null ? "background-color:"+value+"; color:"+value+";"
											 : style + "background-color:"+value+"; color:"+value+";" ;

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		return new TagBuffer( "input" )
					.add( "name"	, newName )
					.add( "id"		, newName , isNull( attributes.get( "id" ) ) )		// 4.3.7.2 (2009/06/15)
					.add( "value"	, value )
					.add( "size"	, size2 )
//					.add( "style"	, "background-color:"+value+"; color:"+value+";" )
					.add( "style"	, inStyle )
					.add( tagBuffer.makeTag() )
					.makeTag( row,value );
	}
}

==> openGion8.0.0.2_src.zip: gf/src/org/opengion/plugin/column/Editor_COLOR.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractEditor;
import org.opengion.hayabusa.db.CellEditor;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.TagBuffer;
import org.opengion.fukurou.util.XHTMLTag;

import static org.opengion.fukurou.util.StringUtil.isNull;				// 6.1.1.0 (2015/01/17)

/**
 * COLOR エディターは、カラムのデータをカラーピッカーで選択する場合に使用するクラスです。
 * 値は#FFFFFFのように#付き7桁で入ります。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ編集
 *
 * @og.rev 5.5.4.0 (2012/07/02) 新規作成
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Editor_COLOR extends AbstractEditor {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "7.0.1.0 (2018/10/15)" ;

	// 6.3.6.1 (2015/08/28) style属性のマージ
	private final String style;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 */
	public Editor_COLOR() {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		style = null;
	}

	/**
	 * DBColumnオブジェクトを指定したprivateコンストラクター。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Editor_COLOR( final DBColumn clm ) {
		super( clm );
		style = attributes.remove( "style" );		// 6.3.6.1 (2015/08/28) あれば、キーから削除。

		attributes.add( "class"		,"colorPicker" );
		attributes.add( "readonly"	,"readonly" );
		tagBuffer.add( XHTMLTag.inputAttri( attributes ) );
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellEditorオブジェクト
	 * @og.rtnNotNull
	 */
	public CellEditor newInstance( final DBColumn clm ) {
		return new Editor_COLOR( clm );
	}

	/**
	 * データの編集用文字列を返します。(色付き)
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 * @og.rev 7.0.1.0 (2018/10/15) style属性の作成に、TagBuffer利用。
	 *
	 * @param	value 入力値
	 *
	 * @return	データの編集用文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final String value ) {
//		// 6.3.6.1 (2015/08/28) style属性のマージ
//		final String inStyle = style == null ? "background-color:"+value+"; color:"+value+";"
//											 : style + "background-color:"+value+"; color:"+value+";" ;

		// 7.0.1.0 (2018/10/15) style属性の作成に、TagBuffer利用
		final String inStyle = new TagBuffer().startCss( null )
										.addOptions( style )						// null で未登録
										.add( "background-color"	, value )
										.add( "color"				, value )
										.add( "cursor"				, "default" )	// 標準のreadonlyを、禁止カーソルにしたため。
										.makeTag();

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		return new TagBuffer( "input" )
					.add( "name"	, name )
					.add( "id"		, name , isNull( attributes.get( "id" ) ) )		// 4.3.7.2 (2009/06/15)
					.add( "value"	, value )
					.add( "size"	, size1 )
					.add( "style"	, inStyle )
					.add( tagBuffer.makeTag() )
					.makeTag();
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。(色付き)
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @og.rev 6.3.6.1 (2015/08/28) style属性のマージ。
	 * @og.rev 7.0.1.0 (2018/10/15) style属性の作成に、TagBuffer利用。
	 *
	 * @param	row   行番号
	 * @param	value 入力値
	 *
	 * @return	データ表示/編集用の文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final int row,final String value ) {
		final String newName = name + HybsSystem.JOINT_STRING + row;

//		// 6.3.6.1 (2015/08/28) style属性のマージ
//		final String inStyle = style == null ? "background-color:"+value+"; color:"+value+";"
//											 : style + "background-color:"+value+"; color:"+value+";" ;

		// 7.0.1.0 (2018/10/15) style属性の作成に、TagBuffer利用
		final String inStyle = new TagBuffer().startCss( null )
										.addOptions( style )						// null で未登録
										.add( "background-color"	, value )
										.add( "color"				, value )
										.add( "cursor"				, "default" )	// 標準のreadonlyを、禁止カーソルにしたため。
										.makeTag();

		// 6.1.1.0 (2015/01/17) TagBufferの連結記述
		return new TagBuffer( "input" )
					.add( "name"	, newName )
					.add( "id"		, newName , isNull( attributes.get( "id" ) ) )		// 4.3.7.2 (2009/06/15)
					.add( "value"	, value )
					.add( "size"	, size2 )
					.add( "style"	, inStyle )
					.add( tagBuffer.makeTag() )
					.makeTag( row,value );
	}
}
